user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
* [PATCH] extsearchidx: symlink .rev and .bitmap files into ALL.git
@ 2021-06-30 19:14 Eric Wong
  0 siblings, 0 replies; only message in thread
From: Eric Wong @ 2021-06-30 19:14 UTC (permalink / raw)
  To: meta

It's possible for these to exist and git can (or may eventually)
take advantage of them to speed up functionality which affects
us.
---
 lib/PublicInbox/ExtSearchIdx.pm | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/PublicInbox/ExtSearchIdx.pm b/lib/PublicInbox/ExtSearchIdx.pm
index a14f0652..e4eaf5be 100644
--- a/lib/PublicInbox/ExtSearchIdx.pm
+++ b/lib/PublicInbox/ExtSearchIdx.pm
@@ -943,9 +943,9 @@ sub symlink_packs ($$) {
 				symlink($idx, "$dst.idx") and
 				-f $idx) {
 			++$ret;
 			# .promisor and .keep are optional
 			# XXX should we symlink .keep here?
-			for my $s (qw(promisor)) {
+			for my $s (qw(promisor bitmap rev)) {
 				symlink("$src.$s", "$dst.$s") if -f "$src.$s";
 			}
 		} elsif (!$!{EEXIST}) {
@@ -1018,7 +1018,7 @@ sub idx_init { # similar to V2Writable
 	if (!mkdir($pd) && $!{EEXIST} && opendir($dh, $pd)) {
 		# drop stale symlinks
 		while (defined(my $dn = readdir($dh))) {
-			if ($dn =~ /\.(?:idx|pack|promisor)\z/) {
+			if ($dn =~ /\.(?:idx|pack|promisor|bitmap|rev)\z/) {
 				my $f = "$pd/$dn";
 				unlink($f) if -l $f && !-e $f;
 			}

^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2021-06-30 19:14 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -943,9 +943,9 @@ sub symlink_packs ($$) {
 				-f $idx) {
 			++$ret;
-			# .promisor and .keep are optional
+			# .promisor, .bitmap, .rev and .keep are optional
 			# XXX should we symlink .keep here?
2021-06-30 19:14 [PATCH] extsearchidx: symlink .rev and .bitmap files into ALL.git Eric Wong

Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).